@@ -10,7 +10,7 @@ from tableau_api_lib.utils import extract_pages
 
 
 def get_all_project_fields(conn):
-    all_projects = extract_pages(conn.query_projects, parameter_dict={'fields': 'fields=_all_'})
+    all_projects = extract_pages(conn.query_projects, parameter_dict={'fields': 'fields=_default_'})
     return all_projects
 
 
