@@ -10,7 +10,7 @@ from tableau_api_lib.utils import extract_pages
 
 
 def get_all_schedule_fields(conn):
-    all_schedules = extract_pages(conn.query_schedules, parameter_dict={'fields': 'fields=_all_'})
+    all_schedules = extract_pages(conn.query_schedules, parameter_dict={'fields': 'fields=_default_'})
     return all_schedules
 
 
