@@ -8,7 +8,7 @@ from tableau_api_lib.utils import extract_pages
 
 
 def get_all_user_fields(conn):
-    all_users = extract_pages(conn.get_users_on_site, parameter_dict={'fields': 'fields=_all_'})
+    all_users = extract_pages(conn.get_users_on_site, parameter_dict={'fields': 'fields=_default_'})
     return all_users
 
 
